@@ -15,9 +15,8 @@
 #     search: string
 #     label_name: string
 #     sort: string
+#     non_archived: boolean
 #
-require_relative 'projects_finder'
-
 class IssuableFinder
   NONE = '0'
 
@@ -40,6 +39,7 @@ class IssuableFinder
     items = by_author(items)
     items = by_label(items)
     items = by_due_date(items)
+    items = by_non_archived(items)
     sort(items)
   end
 
@@ -362,6 +362,10 @@ class IssuableFinder
     end
   end
 
+  def by_non_archived(items)
+    params[:non_archived].present? ? items.non_archived : items
+  end
+
   def current_user_related?
     params[:scope] == 'created-by-me' || params[:scope] == 'authored' || params[:scope] == 'assigned-to-me'
   end
