@@ -1,9 +1,7 @@
-require_relative "base_service"
-
 module Files
   class CreateService < Files::BaseService
     def commit
-      repository.commit_file(current_user, @file_path, @file_content, @commit_message, @target_branch, false)
+      repository.commit_file(current_user, @file_path, @file_content, @commit_message, @target_branch, false, author_email: @author_email, author_name: @author_name)
     end
 
     def validate
@@ -29,7 +27,7 @@ module Files
         blob = repository.blob_at_branch(@source_branch, @file_path)
 
         if blob
-          raise_error("Your changes could not be committed because a file with the same name already exists")
+          raise_error('Your changes could not be committed because a file with the same name already exists')
         end
       end
     end
